Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Agent ¶
func Agent( ctx context.Context, stateServiceClient vakeel_way.StateServiceClient, ) error
Agent sends update requests to the given state service client. It continuously sends update requests until the context is cancelled. Returns an error if sending the update request fails.
Parameters: - ctx: The context.Context to use for the gRPC call. - stateServiceClient: The client for the state service.
Returns: - error: An error if sending the update request fails.
func AgentRegister ¶ added in v1.1.0
func AgentRegister( _ context.Context, register RegisterUseCase, ) error
Types ¶
type RegisterUseCase ¶ added in v1.1.0
type RegisterUseCase interface {
Register() error
}
Click to show internal directories.
Click to hide internal directories.